Operadic categories and Duoidal Deligne’s conjectureThanks: The first author acknowledges the financial support of Scott Russel Johnson Memorial Foundation and Australian Research Council (grant No. DP1095346).Thanks: The second author was supported by Eduard Čech Institute P201/12/G028 and RVO: 67985840.
Abstract.
The purpose of this paper is two-fold. In Part 1 we introduce a new theory of operadic categories and their operads. This theory is, in our opinion, of an independent value.
In Part 2 we use this new theory together with our previous results to prove that multiplicative -operads in duoidal categories admit, under some mild conditions on the underlying monoidal category, natural actions of contractible -operads. The result of D. Tamarkin on the structure of dg-categories, as well as the classical Deligne conjecture for the Hochschild cohomology, is a particular case of this statement.
Key words and phrases:
Operadic category, duoidal category, Deligne’s conjecture1991 Mathematics Subject Classification
Primary 18D10,18D20, 18D50, secondary 55U40, 55P48.Contents
Introduction
In [9] we proposed a notion of center and homotopy center of a monoid in a monoidal category enriched in a duoidal category. Examples include classical centers but also the -category of categories, the symmetric monoidal closed category of -categories, -functors and pseudonatural transformations [22] and Tamarkin’s homotopy 2-category of -categories, -functors and their coherent natural transformations [30].
It is well-known that the center of an associative algebra is a commutative algebra. A homotopical analogue of this statement is the famous Deligne conjecture which states that there is a natural action of an -operad on the Hochschild complex of an associative algebra lifting the Gerstenhaber algebra structure from the cohomology to the chain level. We conjectured in [9] that our generalized (homotopical) center admits a closely related algebraic structure. Namely, there is a natural action of a contractible -operad in the sense of the first author [3] on the homotopical center of a monoid [9, Corollary 11.20]. We call this statement duoidal Deligne’s conjecture. Tamarkin’s main theorem from [30] is a particular case of this conjecture. Classical Deligne’s conjecture also follows from the duoidal version [9, Corollary 11.22]. The main goal of this paper is to prove this conjecture under some mild homotopical conditions on the base symmetric monoidal category
Our secondary goal is to advertise a new theory which, as we believe, has an independent value. During our work on the proof of duoidal Deligne’s conjecture we discovered that the existing language is not adequate for our purposes. Some operad-like structures that we wanted to use were not operads in any of the existing senses. To overcome these difficulties, we introduce a concept of an operadic category and of an operad corresponding to such a category.
Examples of operadic categories are abundant. They include categories like finite sets, finite ordinals, the categories of -ordinals [4] and -trees [3, 10], Barwick operator categories [2], ordered graphs and many other. Examples of the corresponding operads are (colored) classical symmetric and nonsymmetric operads, -operads [3], hyperoperads of Getzler and Kapranov [21], charades of Kapranov [23], &c. As classical operads, our generalized operads have algebras, which now include other operad-like structures such as (wheeled) properads or PROPs, cyclic operads and (twisted) modular operads.
We believe that operadic categories admit a rich and interesting theory. They are closely connected to other existing and emerging approaches to generalized operad-like structures such as Feynman categories of Kaufmann [24], polynomial monads [6], moment categories of Berger [13] and operator categories of Barwick [2]. To keep the focus, we decided to choose a ‘minimalistic’ approach and to include as much or as little theory of operadic categories as necessary for the proof of Deligne’s conjecture. A deeper theory, including -categorical aspects of operadic categories and relation to other notions with more applications, will be developed in subsequent papers.
Plan of the paper
According to our goals we decided to subdivide our paper into two parts. Part 1 contains all necessary definitions and facts about operadic categories.
An operadic category is a category over the (skeletal) category of finite sets whose morphisms come with a finite set of objects of the same category, called fibers. The motivating example is the category of finite sets itself, where the set of fibers of a map is the set of preimages The axioms of operadic category are designed to make the assignment of fibers to morphisms an abstract algebraic structure on a category. Operadic functors are functors which preserve fibers and some other elements of this structure.
With each operadic category one associates its category of operads with values in a symmetric monoidal category. In many respects the category of operads plays the rôle of the presheaf category over a small category, but other aspects of operadic categories make it closer to multicategories. We show that several standard categorical notions such as the left Kan extensions, discrete fibrations, the Grothendieck construction or Beck-Chevalley squares extend to operadic categories and operads. On the other hand, some important notions from the theory of classical operads, such as the Day-Street convolution, multitensors and the condensation can be easily carried over to the context of operadic categories.
Part 2 of our paper shows how all these notions work together in the proof of duoidal Deligne’s conjecture. In Section 5 we describe an operadic category and an -operad that canonically acts on any multiplicative -operad in any duoidal category.
In the subsequent sections we demonstrate that this action induces an action of a colored -operad on the same multiplicative -operad. This induced action is crucial and the most complicated part of our proof. The -operad is constructed as a pullback of the Tamarkin-Tsygan colored symmetric operad [31, 7] whose definition we recall in Section 6. Algebras of are multiplicative nonsymmetric operads. While this observation was enough to prove classical Deligne’s conjecture [7], for the duoidal version we have to take into account that the two units of a duoidal category can be different, though connected by a noninvertible morphism. This asymmetry cannot be captured by the classical approach via symmetric operads. This was our reason for introducing operadic categories.
Once this induced action of is constructed, we obtain the proof of duoidal Deligne’s conjecture using the condensation of [7] generalized to the context of operadic categories. This is the subject of the last section of our paper.
Conventions
Throughout this article, will be a complete, cocomplete closed symmetric monoidal category. A tree will always mean a rooted (i.e. directed) tree [27, II.1.5]. The arity of a vertex of a directed tree is the number of incoming edges of that vertex.
Categories will be denoted by typewriter letters , , , , &c. Exceptions are our basic monoidal category which we keep denoting from historical reasons, and the basic duoidal category used in Part 2. Operads in will be denoted by the calligraphic letters , , &c., while a typical operad in will be denoted by the script . A more specific notation used in Part 2 is summarized in Table 1. Finally, denotes the set of natural numbers (inducing ).
Acknowledgment. We enjoyed the wonderful atmosphere of the Max-Planck Institut für Mathematik in Bonn during the period when the first draft of this paper was completed. We also wish to express our gratitude to C. Berger, R. Garner, R. Kaufmann, S. Lack, R. Street, D. Tamarkin and M. Weber for many useful comments and conversations.
Part I Theory of operadic categories
1. Operadic categories and their operads
Let be the skeletal category of finite sets. The objects of this category are linearly ordered sets Morphisms are arbitrary maps between these sets. We define the th fiber of a morphism , , as the pullback of along the map which picks up the element , so this is an object which is isomorphic as a linearly ordered set to the preimage . Any commutative diagram in
then induces a map for any This assignment is a functor Moreover, for any we have the equality The above structure on the category motivates the following abstract definition.
A strict operadic category is a category equipped with a ‘cardinality’ functor having the following properties. We require that each connected component of has a chosen terminal object , . We also assume that for every in and every element there is given an object which we will call the th fiber of , such that We also require that
- (i)
For any , .
A trivial morphism in is a morphism such that, for each , for some
The remaining axioms for a strict operadic category are:
- (ii)
The identity morphism is trivial for any
- (iii)
For any commutative diagram in
(1) and every one is given a map
such that is the map of sets induced by
We moreover require that this assignment forms a functor . If , the functor is required to be the domain functor
- (iv)
In the situation of (iii), for any , one has the equality
(2) - (v)
Let
be a commutative diagram in and let Then by axiom (iii) the diagram
commutes, so it induces a morphism By axiom (iv) we have
We then require the equality
We will also assume that the set of connected components is small with respect to a sufficiently big ambient universe.
Remark 1.1.
It follows from axiom (iii) that the unique fiber of the canonical morphism is .
A strict operadic functor between two strict operadic categories is a functor over which preserves fibers in the sense that , for any and . We also require that preserves the chosen terminal objects in each connected component, and equality (2). This gives the category of strict operadic categories and their strict operadic functors.
Remark 1.2.
Our notion of operadic category is not invariant under categorical equivalences. It is, nevertheless, very convenient and sufficient for our applications. There is a more general non-strict version of the above definition which we are going to consider in a subsequent paper. We will also consider non-strict operadic functors and operadic natural transformations. We hope to prove a coherence theorem saying that every general operadic category is equivalent in an appropriate sense to a strict one. Since in this paper we only use strict operadic categories we will call them simply operadic categories for brevity.
Example 1.3.
The terminal category with the cardinality functor which sends the unique object of to is operadic.
Example 1.4.
The category of finite ordinals (including the empty one) has an obvious structure of an operadic category
Example 1.5.
The categories and are examples of operator categories in the sense of Barwick [2]. It is easy to see that, in fact, any Barwick’s operator category is equivalent to an operadic category in our sense. Recall that an operator category is an essentially small category which satisfies the following conditions:
- (i)
the set of morphisms is finite for any pair of objects ,
- (ii)
the category has a terminal object , and
- (iii)
there is a pullback of along for any morphisms and .
To find an equivalent operadic category we take a skeletal version of fix as the chosen terminal object, take as the cardinality of and choose pullbacks , as the fiber functors. The rest of the structure is clear.
Example 1.6.
Each category determines the ‘tautological’ operadic category which, as a category, is with a formally added terminal object . The cardinality is defined by
The axioms dictate that the only maps that have fibers are with the unique fiber , and the identity whose fiber is . This construction constitutes a fully faithful embedding of the category of small categories to the category of operadic categories.
Example 1.7.
Let be a set. A -bouquet is a map where In other words, a -bouquet is an ordered -tuple , of elements of It can also be thought of as a planar corolla whose all edges (including the root) are colored. The extra color is called the root color. The finite set is the underlying set of the bouquet .
A map of -bouquets whose root colors coincide is an arbitrary map of their underlying sets. Otherwise there is no map between -bouquets. We denote the resulting category of -bouquets by .
The cardinality functor assigns to a bouquet its underlying set . The fiber of a map given by over an element is a -bouquet whose underlying set is the root color coincides with the color of and the colors of the elements are inherited from the colors of the elements of .
It is easy to see that is an operadic category with its set of connected components. It is an example of an operadic category whose fibers are not pullbacks. It has the following important property:
Proposition 1.8.
For each operadic category with , there is a canonical operadic ‘arity’ functor giving rise to the factorization
| (3) |
of the cardinality functor .
Proof.
Let the source of be the set of fibers of the identity . We define as the bouquet , where associates to each fiber the corresponding connected component , and . We leave as an exercise to check that the assignment extends into an operadic functor. ∎
The assignment extends to a functor , and the functor is the initial object of the comma-category . This explains why the bouquets will play such a prominent rôle among operadic categories. Indeed, the arity functor will be used to define the endomorphism operads in Example 1.19.
Proposition 1.9.
Pullbacks in the category of categories create pullbacks in the category of operadic categories and operadic functors.
Proof.
Let us consider the ordinary pullback
| (4) |
of the diagram of operadic categories and their operadic functors. We may assume that objects of are pairs , , , such that . Morphisms in are couples , where is a morphism in and a morphism in such that . The functors and are the obvious projections to the first resp. the second factor.
We equip with a structure of an operadic category as follows. We define the cardinality functor by .11 1 Since we could as well put . The chosen terminal objects are
The fibers are defined componentwise, i.e. for a morphism we put
Notice that, since and are operadic functors,
so indeed .
We leave the verification that the diagram (4) is indeed a pullback in the category of operadic categories as an exercise. ∎
Pullbacks can be used to define colored versions of operadic categories. Given an operadic category and a finite set , we define the operadic category of -colored objects in as the pullback
| (5) |
Notice that .
Remark 1.10.
Since is the terminal object in the category of operadic categories, the pullback is actually the product in
A -collection in is a collection of objects of indexed by the objects of the category . The category of -collections in will be denoted . For a -collection and a morphism let
In the following definition we tacitly use equalities (2).
Definition 1.11.
An -operad is a collection in together with units
and structure maps
satisfying the following axioms.
- (i)
Let be morphisms in and as in (1). Then the following diagram of structure maps of combined with the canonical isomorphisms of products in commutes:
- (ii)
The composition
is the identity for each , as well as the identity is
- (iii)
the composition
Notice that for an arbitrary operad and , with the multiplication
forms a unital monoid in .
A morphism of -operads in is a collection of -morphisms commuting with the structure operations. We denote by the category of -operads in . Each operadic functor obviously induces the restriction .
We can put the definition of -operad in a -categorical context as follows22 2 We were inspired by the definition of a non-symmetric operad as a strict monoidal lax-functor given by Day and Street in [19].. Let denote the symmetric monoidal bicategory with one object and as its category of morphisms . Recall that a part of a lax-functor structure on from a category to the bicategory are morphisms
for each commutative diagram like (1), as well as morphisms For such a lax-functor and an object we denote .
Definition 1.12.
An operad-like functor from to is a lax-functor equipped, for each with fibers , , with an isomorphism
| (6) |
which satisfies the following axioms:
- (i)
For any commutative diagram (1) the following diagram commutes
where the bottom vertical arrow on the left side is an identity due to equality
(7) and the up-going right vertical arrow is given by the lax-constraints induced by commutative diagrams:
- (ii)
For each object , the following diagram commutes
The proof of the following lemma is straightforward:
Lemma 1.13.
The category is equivalent to the category of operad-like functors from to and their lax-natural transformations which commute with the structure isomorphisms (6).
Example 1.14.
Operads over the terminal category of Example 1.3 are monoids in .
Example 1.15.
The category of operads over the category is isomorphic to the category of classical symmetric operads. Operads over are ordinary non- operads [5, Sec. 3, Prop. 3.1]. Applying the construction of diagram (5) to the operadic category we obtain the category describing -colored non--operads. More examples of this construction will be given in Section 5.
Example 1.16.
Example 1.17.
Example 1.18.
The category of -operads in has a monoidal structure given by the ’componentwise’ multiplication in . The unit for this structure is the operad with for each . Clearly for any operadic functor .
Example 1.19.
Definition 1.20.
An algebra over an -operad in is a collection , , equipped with an -operad map .
An algebra is thus given by suitable structure maps
where denotes, as before, the set of fibers of the identity . This notion of -algebras will further be generalized in Section 3.
Example 1.21.
The category of stable labelled graphs [26, Section 7] is an operadic category. Morphisms are given by contractions of subgraphs. The cardinality functor associates to a graph its set of vertices. Fibers of a morphism are the subgraphs contracted to a vertex.
Example 1.22.
This is our only example of a large operadic category. Let be an abelian category and let be its subcategory of epimorphisms. The cardinality functor on maps all objects to the one point set The (unique) fiber of any morphism is its (chosen) kernel. It is easy to check that this defines an operadic category structure on An -operad in the category of vector spaces is the same as a charade over in Kapranov’s sense [23, Definition 3.2].33 3 Generally speaking, is not a strict operadic category but we can easily “strictify” it if we use a skeletal version.
1.1. The category of -trees
We are going to recall briefly the category of -trees, for ; the details can be found in [3, Sec. 3, Example 8] or [10]. The category of -trees is the terminal category . Its unique object is denoted by .
The category of -trees is the category of finite ordinals , , and their order-preserving maps. As usual, we interpret for as the empty set. The terminal object of is . When the meaning is clear from the context, we will simplify the notation and denote the object simply by . The category is isomorphic to the operadic category recalled in Example 1.4.
Let . A -tree is a chain
| (9) |
of morphisms in . A morphism
| (10) |
of -trees is a diagram in
such that
- (i)
is order preserving and
- (ii)
for any , , and , the restriction of to is order-preserving.
We denote by the category of -trees and their morphisms as defined above. Its terminal object is the -tree , its initial object is . Notice that we have the obvious truncation functors
One also has the suspension functor , , that to an -tree as in (9) associates the -tree
An -leaf (or a leaf of height ) of a -tree as in (9) is, for , by definition an element of . For an -leaf is an element such that . We denote by the set of all -leaves of .
Let be a map of -trees as in (10) and a -leaf of . Let us define the fiber over as the chain
| (11) |
of the restrictions of the maps in (9). Analogously one may define also fibers over the -leaves for , but we will not use them in this article.
The category with the cardinality functor , with the fibers defined as above and the chosen terminal object the -tree , is an operadic category. Operads in are precisely -operads in the monoidal globular -category , see [9, §11.3].
1.2. The category of -ordinals
Let, as in the Section 1.1 , . Recall [4, Sec. II] that a -ordinal is a finite set equipped with binary relations such that
- (i)
is nonreflexive,
- (ii)
for every pair of distinct elements of there exists exactly one such that
- (iii)
if and then .
A morphism of -ordinals is a map of the underlying sets such that in implies that
- (i)
for some , or
- (ii)
, or
- (iii)
for .
Let be the skeletal category of -ordinals and their morphisms. The category is operadic. The cardinality associates to a -ordinal its underlying set (denoted again). The fiber of a map over is the preimage with the induced structure of a -ordinal. The category is connected, the unique terminal object being the one-point -ordinal . Operads in are pruned -operads in the monoidal globular -category [4].
There is a natural -ordinal structure on the set of -leaves of each -tree in . Let be as in (9) and its distinct -leaves. We say that if precedes in and is such that
but
If such a does not exist, we put . It is easy to show that this construction extends to an operadic functor
| (12) |
On the other hand, can be identified with the full subcategory of consisting of pruned trees. Recall that a -tree as in (9) is pruned if all are epimorphisms. Equivalently, all leaves of are its -leaves, so is “fully grown.” For example, the -ordinal
is represented by the following pruned tree
| 0,-1.7822068)(6.81,1.7822068) |
See [4, Theorem 2.1] for a more detailed discussion. We thus have an inclusion of categories which is left adjoint to the pruning functor (12).
It will sometimes be useful to identify a -ordinal with the corresponding pruned tree . The functor then appears as the pruning associating to each its maximal pruned subtree. We must emphasize that is not an operadic functor, since it does not preserve fibers in general. It is only lax operadic in an appropriate sense.
2. Discrete fibrations of operadic categories
Definition 2.1.
An operadic functor is called a discrete operadic fibration if
- (i)
induces an epimorphism and
- (ii)
for any morphism in and any , where , such that
there exists a unique in such that
We have the following simple
Lemma 2.2.
A discrete operadic fibration induces an isomorphism .
Proof.
Assume that , , , are chosen terminal objects in components of the category such that for . Then (ii) of Definition 2.1 taken with , the identity map, and produces a map whose unique fiber is . Since is the domain functor by (iii) of the definition of the operadic category, , so is in fact a map , therefore and belong to the same component of , i.e. . ∎
For an -operad and put
| (13) |
Proposition 2.3.
Assume that is a discrete operadic fibration. Then (13) is the underlying collection of a naturally defined -operad.
Proof.
For each and , , we need the structure map
Expanding the definition of and invoking the distributivity of the monoidal product over coproducts we see that it is the same as to give a map
It clearly amounts to specifying, for each ’s and as above, a map
| (14) |
The defining property of discrete operadic fibrations provides a unique with , and a morphism such that for . We then choose (14) to be the composition
where is the structure map of the -operad and the canonical map to the coproduct.
Let , , be a chosen terminal object of a component of . By Lemma 2.2, there is a unique chosen terminal object , , such that . We define the unit as the composition
of the unit map for with the coprojection. Since all constructions were functorial lifts of the operad structure of , the resulting structure is an operad again. ∎
Theorem 2.4.
Let be a discrete operadic fibration of operadic categories. Then the assignment described above defines a left adjoint to the restriction functor .
Proof.
We need to establish, for and , a natural isomorphism
There is an isomorphism of the sets of morphisms of collections
| (15) |
This follows immediately since (13) is the formula for the left Kan extension along the induced functor between the discrete categories of objects.
Let now be the monoidal category of sets, a discrete operadic fibration and the terminal -operad with . Theorem 2.4 gives the operad
| (16) |
with .
Vice versa, assume that one is given an operad . One then has the category whose objects are for some . A morphism from to is a couple consisting of a morphism in and of some , , such that
where is the structure map of the operad . Compositions of morphisms are defined in the obvious manner. The category thus constructed is clearly an operadic category such that the functor given by
| for and |
is a discrete operadic fibration. We call this construction the operadic Grothendieck construction. It is a direct generalization of the classical Grothendieck construction for presheaves [29, p. 44] as the following proposition shows.
Proposition 2.5.
The above construction establishes an equivalence between the category of -operads in and the category of discrete operadic fibrations over .
Proof.
A direct verification. ∎
Example 2.6.
As we saw in Example 1.16, -operads in the operadic category of Example 1.6 such that are presheaves on . The restriction of the correspondence of Proposition 2.5 to operads with this property is an equivalence between the category of presheaves on and the category of discrete fibrations of categories. Proposition 2.5 therefore indeed generalizes the discrete version of the Grothendieck construction.
Proposition 2.7.
Assume that in the pullback (4), the functor is a discrete operadic fibration. Then is a discrete operadic fibration, too.
Proof.
We rely on the notation in the proof of Proposition 1.9. Suppose we are given a morphism in with fibers , . Suppose we are also given objects and of the category such that and for each . We must find a unique in such that and for each .
It follows from definitions that implies , implies and implies . Since and are objects of we see that , and for all . Similarly, we conclude that .
We therefore need to prove the following statement. Given in with fibers and objects of , , such that , and , there exists a unique in such that and . The above statement however follows from the lifting property in the discrete operadic fibration applied to the data and , . This finishes the proof. ∎
We close this section by proving that squares of adjoint functors between the associated categories of operads induced by pullbacks of discrete operadic fibrations satisfy the Beck-Chevalley property [29, p. 205]. Therefore operads over operadic categories behave similarly as presheaves over small categories.
Proposition 2.8.
If in the pullback of operadic categories (4) the functor is a discrete operadic fibration, then the induced functors between the associated categories of operads satisfy the Beck-Chevalley condition, meaning that there is a natural isomorphism
| (17) |
for any operad .
Proof.
Notice that the functor is a discrete operadic fibration by Proposition 2.7. We will use the explicit description of the left adjoint along discrete fibrations provided by Theorem 2.4. For it gives
therefore, for ,
On the other hand,
therefore indeed for each . In the last display we used the fact that implies so, since , we have the equality . ∎
3. -multi(co)tensors and generalized algebras of -operads
We start by showing how the standard notion of a multitensor on a -category , see [11, Def. 2.1] or [5, 18], generalizes to the realm of operadic categories. Let be the endomorphism -operad of , so is, for , the category of -functors The restriction along the cardinality functor gives a categorical -operad . Let be the terminal categorical -operad. An -multitensor on is then a lax-morphism of categorical operads . Unpacking this definition we obtain:
Definition 3.1.
An -multitensor on a -category is an -collection of -functors
equipped with
- (i)
-natural transformations
defined for any in with fibers , and
- (ii)
-natural transformations (the units)
satisfying the obvious associativity and unitality conditions.
Multitensors create operads, as shown in the following lemma whose simple proof we leave to the reader. For an object , let denote the set of connected components of the fibers of the identity , and the connected component of , cf. the proof of Proposition 1.8.
Lemma 3.2.
Let be an -multitensor on a -category and an arbitrary collection in . Then the collection
with the enriched hom
is a natural -operad in .
Dually, we introduce -multicotensors on as colax-morphisms of the categorical -operads . An explicit definition can be obtained by inverting arrows in Definition 3.1. Multicotensors create operads in a similar way as multitensors do:
Lemma 3.3.
Let be an -multicotensor on a -category and an arbitrary collection of objects of . Then the collection
with and having the meaning as in Lemma 3.2, is a natural -operad in .
Example 3.4.
Let be the terminal category of Example 1.3. A -(co)multitensor on is the same as a -(co)monad on .
For an arbitrary operadic category and , there is an operadic functor which sends the unique object of to . Restricting along this functor we verify that (resp. ) is a -monad (resp. -comonad) on for an arbitrary -multitensor (resp. multicotensor ).
Example 3.5.
The tensor product of a symmetric monoidal -category gives rise to a -multitensor on , which is simultaneously a -multicotensor on . Namely, for a finite set of cardinality and we put
For any operadic category we then have an -multitensor on (which is also a -multicotensor) given by restricting along the cardinality functor:
The case of the above construction along with Lemmas 3.2 and 3.3 explains the standard fact that an object of a symmetric monoidal category has both the (classical) endomorphism and coendomorphism operads, see [27], Definitions II.1.7 and II.1.9.
Definition 3.6.
Let be a fixed -multicotensor and an -operad. An algebra of in is a -collection in with a morphism of -operads
Example 3.7.
If and , then -algebras in the sense of the above definition are the same as -algebras of Definition 1.20.
Assume that is a -multicotensor and suppose that is cocomplete as a -category. This means, in particular, that there is a left action functor which we denote by , believing that it would not lead to confusion. We have an adjunction
for any and .
Since is a -functor in each variable, there is for each , , , and , a -natural transformation
called the strength of . We will require that interacts with the left -action in such a way that the following conditions are satisfied:
- (i)
The diagram
commutes for any , and .
- (ii)
Let be a morphism in with fibers . Let , and , be such that belongs to . Then the diagram
commutes for any and .
Definition 3.8.
An -multicotensor on a cocomplete -category satisfying properties (i) and (ii) above will be called strong. We will call a -category equipped with a strong multitensor for which the comonad of Example 3.4 is the identity comonad for each a colax -monoidal -category.
Remark 3.9.
For a -collection in and denote
The structure of a -algebra on a -collection in a colax monoidal -category can be expressed in terms of an action defined as a collection of morphisms
satisfying the following conditions:
- (i)
The square
in which is the counit of the comonad , commutes for any
- (ii)
For any morphism in with fibers , the following diagram in which commutes
4. Convolution and condensation
The condensation described in this section creates, in a controlled manner, out of colored operads and their algebras, non-colored ones. The main statement of this section is Proposition 4.6.
Fix a finite set and consider the pullback in (5). Objects of can be interpreted as objects of colored by elements of . A typical object of will therefore be denoted by , where and .
The operadic category contains a full operadic subcategory 55 5 “L” abbreviating “linear.” whose objects are objects of of the form , , It is easy to see that -operads are precisely -families of -enriched categories with the set of objects . In other words, , where denotes the category of -categories with the set of objects , and the set is considered as a discrete category.
The inclusion induces the restriction functor between the categories of operads. We define the functor as the composition
where the coproduct exists because is cocomplete.
Definition 4.1.
We will call the -enriched category the underlying category of an -operad in .
Explicitly, the set of objects of is , while the enriched hom-set between and is
Since are the chosen terminal objects of , we have the identity morphisms
given by the operad units of . The composition in is induced by the (unique) maps between objects of the form , , .
Let be a colax -monoidal -category with a multicotensor as in Definition 3.8. We are going to define the convolution product on the category . Assume first for simplicity that is connected so that the objects of are elements of . For any , , the operad generates a -functor
defined on objects by
| (18) |
To see how acts on morphisms, we observe that in we have morphisms of the form
whose underlying morphism in is the identity of . The multiplication in the -operad with respect to these morphisms induces the contravariant part of the functor . The covariant part is induced by the multiplication in corresponding to the morphisms in of the form
For as above and , the convolution product is given by the coend in :
| (19) |
The above constructions easily extend to the case of an arbitrary , we just take the products of the corresponding constructions for the individual connected components.
The convolution (19) generalizes the Day-Street convolution product [18] of a substitude related to an ordinary (that is -) operad. If is a symmetric monoidal -category and is the -multicotensor from Example 3.5, many standard facts about the convolution remain valid in this generalized situation. For example we have
Proposition 4.2.
The convolution product determines an -multitensor on whose unital part is the identity monad.
Remark 4.3.
The -multitensor structure of is induced by the -multitensor structure of the -multicotensor . The fact that is both a multicotensor and a multitensor makes this situation very special – the convolution product (19) need not be a -multitensor for general . To simplify the notation, we will sometimes write instead of .
An -multicotensor on induces an -multicotensor on by ‘forgetting the colors’
| (20) |
which in turn restricts to an -multicotensor . Since, by assumption, is the identity comonad for each , the colax unitality of multicotensors gives natural morphisms
| (21) |
Let now be an algebra of an -operad in as in Definition 3.6. The action induces, via the restriction along the inclusion combined with the canonical transformations (21), an action
where is the obvious identity -multitensor on . This gives rise to a functor
| (22) |
from the category of -algebras in to the functor category . If is connected, the algebra is a collection in , the functor takes to , and the map
of the enriched hom-sets is given by the -algebra structure of . The description of for a general is similar.
In the particular case when is a symmetric monoidal -category, is a multitensor on by Proposition 4.2. It turns out that is an algebra over in the sense of the following definition.
Definition 4.4.
An algebra over an -multitensor on a -category is an object equipped with a family of morphisms
such that
- (i)
the composition is the identity for each , and
- (ii)
the diagram
commutes for any morphism in with fibers .
As in the classical case [7, Proposition 1.8] we obtain
Proposition 4.5.
The functor induces an isomorphism between the category of -algebras in and the category of -algebras in .
Let us return to a general colax -monoidal -category . Assume that, in addition, is complete as a -category, so we have cotensors such that
For an -algebra in and an object of the functor category we define the -totalization of as the end
| (23) |
Since is a multitensor, the -collection with
is an -operad in by Lemma 3.2. The main statement of this section reads:
Proposition 4.6.
Let be an -operad in and a -algebra in . Then the -collection is a natural -algebra.
Definition 4.7.
We will call the -operad the -condensation of and its algebra the -totalization of
Remark 4.8.
Proof of Proposition 4.6.
We will assume for simplicity that is connected, the general case can be handled similarly. The action
| (24) |
where , will be constructed using a natural morphism
| (25) |
To simplify the notation, we will implicitly assume that the symbols and denote objects of the underlying category . We will also drop from the notation, writing instead of . Notice that the target of (25) is equal to
so the morphism (25) is the same as a family of morphisms
which satisfy some obvious naturality conditions. By adjunction, this amounts to a family of morphisms
We also have, for each , the evaluation morphisms
which induce a map
Composing this map with the canonical coprojection to the coend
we obtain the required morphism (25). The necessary naturality conditions for the above construction is obvious.
Let us finally explain how the map in (25) leads to the action (24). To this end, observe that a -algebra structure on generates a morphism
| (26) |
The action (24 is then the composition
whose last arrow is generated by (26). We leave a straightforward but tedious verification that this composition is, indeed, a -algebra structure to the reader. ∎
Part II Duoidal Deligne’s conjecture
Reminders
In this part we work with many particular examples of operadic categories and their operads. We included Table 1 to simplify the reader’s navigation through them.
| Categories | |||
| Name: | type of objects: | introduced in: | typical object: |
| Batanin’s -trees | Section 1.1 | ||
| -colored -trees | Section 5.1 | ||
| -ordinals | Section 1.2 | ||
| -colored -ordinals | Section 5.1 | ||
| trees with levels | Section 5.2 | ||
| -labelled trees | Section 6 | , | |
| -labelled trees | Section 6 | , | |
| trees with labeled 0,-0.20138916)(0.40277833,0.20138916) -vertices | Proof of Lemma 7.5 | ||
| trees with labeled 0,-0.20138916)(0.40277833,0.20138916) -vertices | Proof of Lemma 7.5 | ||
| Operads: | |||
| Name: | type of operad: | introduced in: | typical element: |
| -colored -operad | Section 6 | tree | |
| -colored -operad | Definition 6.1 | -labelled tree | |
| pruned -colored -operad | pullback (54) | -labelled tree | |
We also briefly recall, following [9] closely, duoidal categories and the necessary related notions.
A duoidal -category is a pseudomonoid in the 2-category of monoidal -categories, lax-monoidal -functors and their monoidal -transformations. Explicitly, a duoidal -category is a quintuple such that
- (i)
and are monoidal -categories, equipped with
- (ii)
a -natural interchange transformation
(27) - (iii)
a map
- (iv)
a map and
- (v)
a map
The above data should enjoy the coherence properties listed e.g. in [9, p. 1816]. Moreover, we require that is a monoid in and a comonoid in .
A duoidal category is called strict if both monoidal categories and are strict monoidal categories. Since every duoidal category is equivalent to a strict one by [9, Theorem 2.16], we assume that all duoidal categories in this article are strict.
A -operad in a duoidal category is a collection of objects of such that
- (i)
for each integers , , one is given a structure morphism
(28) - (ii)
one is given a map (the unit) and
- (iii)
a left -module structure
such that appropriate axioms are satisfied, see [9, p. 1825] for details. An example is the operad with for each [9, Example 4.4]. Recall finally that a multiplicative -operad is a -operad equipped with an operad morphism
| (29) |
For a duoidal category we denote by the -category of -enriched categories. As observed by Forcey [20], has a monoidal structure. The tensor product of two -categories and is given by the cartesian product on the objects level while
The unit for this tensor product is the category which has one object and
A monoidal -category is defined as a pseudomonoid in the monoidal -category , see [9, pp. 1820–21] for a detailed description of this structure. Each object has its endomorphism -operad in with components
see [9, Def. 4.7].
A monoid in is a lax monoidal functor . More explicitly, a monoid in is an object together with:
- (i)
a morphism (neutral element)
- (ii)
a morphism (multiplication) and
- (iii)
a morphism (the unit) in .
These data should satisfy axioms listed in [9, p. 1823]. The endomorphism -operad of a monoid is multiplicative by [9, Prop. 4.9].
The center of a monoid is the following equalizer in :
| (30) |
The center has a natural structure of a duoid (double monoid in the terminology of [1]) in . This is, by definition, an object together with
- (i)
a structure of a monoid with respect to the first monoidal structure of , and
- (ii)
a structure of a monoid with respect to the second monoidal structure of
such that suitable axioms listed in [9, p. 1818] are satisfied.
5. Operadic categories of trees and ordinals.
In this section we introduce several operadic categories of colored trees and ordinals, and study various functors between them. We also define endomorphism operads of collections in duoidal categories and prove, in Theorem 5.4, the existence of canonical actions on multiplicative -operads.
5.1. The category of coloured -trees
We will need the -colored version of the category of -trees recalled in Section 1.1. It is constructed by taking and in the pullback (5). Explicitly, an -colored -tree is a couple consisting of a -tree and of a coloring of its set of -leaves plus one more color interpreted as the ‘output’ color of . Morphisms are morphisms of the underlying -trees if , while there are no morphisms if . This explicit description follows the ideas of Tamarkin’s [30].
The category with is operadic. The fiber of a map over a -leaf is the fiber as in (11), with the coloring of its -leaves induced by and the output color . One has , the chosen terminal object for being the terminal -tree with its unique -leaf colored by and the output color .
One analogously defines an -colored version of the operadic category of -ordinals of Example 1.2. We leave its detailed description to the reader. One has , the chosen terminal object for being the terminal -ordinal colored by , with the output color .
In the rest of this article we will however need the categories and , resp. their colored versions and , only for .
Definition 5.1.
We will call -operads, resp. -operads, -operads, resp. -colored -operads. Similarly, -operads, resp. -operads, will be called pruned -operads, resp. pruned -colored -operads.
Proposition 5.2.
There is a natural -multicotensor on any duoidal -category . If is a cocomplete -category then the multicotensor is strong.
In particular, each -colored collection of objects in admits its -colored endomorphism -operad .
Proof.
The proof is based on a simple modification of a construction given in [9, p. 1853]. Let be a -tree. Let the -truncation of be , with its set of -leaves over the -vertex being , and let be a family of objects in
We then define, for ,
| (31) |
With this notation,
The counit of the multicotensor is the identity. The comultiplication
| (32) |
corresponding to a morphism in with fibers can be described by induction. We do not provide the details here but refer to the construction of the morphism in the proof of [9, Lemma 11.13] which is exactly the comultiplication in the case when all members of the family are equal to the same object The argument however does not depend on this difference. We will repeat the same kind of construction in the description of the endomorphism -operad in the second part of this proof.
The proof that is a strong multitensor also goes by an induction following the construction of the comultiplication, using the fact that both are -functors and the interchange morphism (27) is a -natural transformation. We leave the details to the reader.
As shown in (20), the -multicotensor induces an -multicotensor . The -colored -operad of an -collection in is the endomorphism operad related to this multicotensor as in Lemma 3.3. We describe it in detail because we will need this description later.
We start by associating, to each -colored -tree , the -power of as follows. Let the -truncation of the underlying -tree be , with its set of -leaves over the -vertex being .
We then define, for ,
| (33) |
With this notation,
We believe that the portrait of in Figure 1 borrowed from [9] clarifies our definition.
Define finally
where is the output color of . Let us describe the operad multiplication
| (34) |
corresponding to a morphism in with fibers . For
we use an auxiliary natural morphism
| (35) |
described below, and define by the formula
Let us define (35). Suppose first that , so is the suspension of the -tree . In this case the exchange rule (27) in induces a natural map
and is the composite
To address the general case denote, for , by the colored -tree obtained by identifying the root of with the root of .77 7 In [9] we denoted this operation by . Observe that
| (36) |
A general uniquely decomposes into the product of the suspensions of -trees; is then of the form
| (37) |
Suppose the fibers of are , , then the fibers of are
For we define by
| (38) |
where we tacitly used (36). This defines (35) for arbitrary trees. ∎
5.2. The category of levelled trees
The category has objects planar rooted trees with three types of vertices: ‘white’ vertices 0,-0.20138916)(0.40277833,0.20138916) , ‘vertical’ vertices 0,-0.20138916)(0.40277833,0.20138916) and ‘horizontal’ vertices 0,-0.19711548)(0.39423096,0.19711548) .88 8 The terminology will be explained in Section 5.3. These vertices may have arbitrary arities and are lined up into levels of two types:
- (i)
levels consisting of white vertices 0,-0.20138916)(0.40277833,0.20138916) and/or vertical vertices 0,-0.20138916)(0.40277833,0.20138916) , and
- (ii)
levels consisting only of horizontal vertices 0,-0.19711548)(0.39423096,0.19711548) .
An example of a tree in is given in Figure 2 which uses the convention that levelled trees are drawn horizontally, with the root on the left.
2,-5.75)(21.006176,4.9)
Morphisms in are generated by three types of ‘elementary’ morphisms:
Type 1. Maps of trees , where is obtained from by choosing two adjacent levels and contracting all edges connecting vertices in these two chosen levels. This contraction results in a single level with vertices determined by the following rules:
- (i)
contracting an edge adjacent to a 0,-0.20138916)(0.40277833,0.20138916) -vertex produces a 0,-0.20138916)(0.40277833,0.20138916) -vertex,
- (ii)
contracting an edge connecting two 0,-0.20138916)(0.40277833,0.20138916) -vertices or a 0,-0.19711548)(0.39423096,0.19711548) -vertex with a 0,-0.20138916)(0.40277833,0.20138916) -vertex produces a 0,-0.20138916)(0.40277833,0.20138916) -vertex and
- (iii)
contracting an edge connecting two 0,-0.19711548)(0.39423096,0.19711548) -vertices produces a 0,-0.19711548)(0.39423096,0.19711548) -vertex.
If we ‘order’ the types of vertices by
| (39) |
then the above rules say that the ‘higher takes everything.’
Type 2. Maps of trees , where is obtained from by replacing a 0,-0.20138916)(0.40277833,0.20138916) -vertex by a 0,-0.20138916)(0.40277833,0.20138916) -vertex of the same arity, or by replacing all 0,-0.19711548)(0.39423096,0.19711548) -vertices in the same level by 0,-0.20138916)(0.40277833,0.20138916) -vertices. Therefore only replacements that increase order (39) are allowed.
Type 3. Maps of trees , where is obtained from by introducing a new level consisting only of 0,-0.20138916)(0.40277833,0.20138916) -vertices of arity .
We require the following relations between these elementary morphisms: a contraction of two levels does not depend on the order, contractions commute with replacement of vertices, and introducing a level and then contracting it is an identity morphism.
The category is operadic. The cardinality functor assigns to the set of its white vertices. The fibers of a map are preimages of white vertices of . Trees in belong to the same connected component if they have the same arity (= number of input edges), one therefore clearly has . The (in this case unique) terminal objects are white corollas of arity .
There is an operadic functor
| (40) |
assigning to an -colored -tree defined as follows. Assume that the white and vertical vertices of are lined up, from the root down, as in the table
| (41) |
(the table therefore does not show type (ii) levels). The -truncation of is the -ordinal represented by the corolla with leaves numbered from the left to the right. The leaves of are elements of the set
| (42) |
The leaf is connected to the th -vertex . Finally, the color of the leaf is the arity of the vertex , while the output color of is the arity of . We put . An example of this construction is in Figure 3. Observe that the functor in (40) does not see horizontal vertices.
0,-1.24)(6.5653358,1.54)
5.3. Endomorphism object for levelled trees
By Proposition 5.2, each collection of objects of a duoidal category has its -colored endomorphism -operad . Likewise, one can define a -collection which becomes, under the mild assumption of the commutativity of diagram (49) below, an operad in .
Its construction is similar to the one in the proof of Proposition 5.2. Assume that all (not only 0,-0.20138916)(0.40277833,0.20138916) - and 0,-0.20138916)(0.40277833,0.20138916) -) vertices of a leveled tree are organized as in the table
| (43) |
Notice that necessarily . Then we define, for ,
where, for ,
| (44) |
Vertical vertices 0,-0.20138916)(0.40277833,0.20138916) are therefore represented by the vertical unit and the horizontal vertices 0,-0.19711548)(0.39423096,0.19711548) by the horizontal unit , which explains the terminology. Finally we put
or, in the expanded form,
| (45) |
and define with the arity of .
One has a natural morphism of -collections
| (46) |
whose components
are induced by a natural map
| (47) |
defined as follows. Let us introduce first an auxiliary reduced -power
whose factors are, for , given as
Clearly, is obtained from by replacing multiple -powers of by a single instance of . The comonoid structure
| (48) |
therefore gives rise to a canonical map . More precisely,
where , , are the following canonical morphisms.
If the th level of is of type (i), then is the identity . When the th level is of type (ii), then by definition while (-times). In this case we take as the map given by iterating the comonoid structure of .
Comparing the definitions of and we see that differs from by (possibly multiple) -products with and/or -products with . Recalling that (resp. ) is the unit for the horizontal (resp. vertical) multiplication in , we conclude that and are canonically isomorphic. The map in (47) is the composition .
Remark 5.3.
One can check that if the diagram
| (49) |
induced by the canonical map and by the unit constraint for commutes, the construction of Section 5.3 gives rise to an -multicotensor that induces a natural -operad structure on .
Theorem 5.4.
Proof.
The map (29) gives rise to a map and, when precomposed with the canonical map , to a map for each . By the definition of , morphism (50) is determined by specifying a map for each , where is the arity of . Assume again that the vertices of are as in table (43) and denote, only for purposes of this proof,
| (52) |
where is the arity of the vertex , , . It is clear that the structure morphisms (28) of the -operad give rise to a map .
For as in (44) define by
Comparing (52) and (45), we see that the above maps assemble to a morphism
| (53) |
We finally define as the composite
The category was designed to model the ‘pasting schemes’ for multiplicative -operads and all related constructions were ‘tautological.’ This makes the desired properties of the above objects obvious. ∎
6. The Tamarkin operad
We are going to give an alternative definition of Tamarkin’s operad acting on dg-categories and study various related categories and operads. The second part of this section is devoted to the construction of the functor (56) needed in Section 7. We consider as in the introduction to [7] the pruned -colored -operad given by the pullback
| (54) |
where is the second filtration of the lattice-path operad, is the second filtration of the complete graph operad of Berger [12], is the complexity index functor and is the canonical internal -operad in consisting of -ordinals. The prominent rôle of is given by the fact that the operad of [30, §5.6.1] acting on dg-categories equals its restriction along the pruning functor (12). To keep the notation compatible with the rest of the paper, we denote the Tamarkin operad by and take the above observations as its definition.
Definition 6.1.
The Tamarkin operad is the restriction of the pullback (54) along the pruning functor .
An alternative description of is given in Remark 7.2. Without going into details of all objects above, we give below an explicit description of and the related objects.
It was shown in [8, Prop. 4.10] or [7, Prop. 2.14] that is isomorphic to the Tamarkin-Tsygan operad [31]. Our exposition will use this description of . The operad is an ordinary symmetric -colored operad in the monoidal category of sets. Its component is the set of planar rooted trees with input leaves and two types of vertices:
- (i)
white vertices 0,-0.20138916)(0.40277833,0.20138916) labelled such that the th vertex has arity , and
- (ii)
black vertices 0,-0.19711548)(0.39423096,0.19711548) of arbitrary arities different from 1.
We moreover require that has no internal edge connecting two black vertices. An example is given in Figure 4.
7,-5.462137)(18.44407,3.2)
The symmetric groups permute the labels of white vertices. The -operation
inserts the tree to the th vertex of and contracts the edges connecting two black vertices if necessary. The units are represented by planar corollas whose unique vertex is white.
There is a canonical complementary order [4, Def. 2.2] on the set of white vertices of a tree given as follows. For ,
- (i)
if and only if there is a directed path in from to , and
- (ii)
if and only if the edge path connecting with the root lies on the left from the path connecting to the root, where ‘left’ refers to the planar structure of .
The following definition will be useful in the sequel; recall that -colored -ordinals were reviewed in Section 5.1.
Definition 6.2.
An -labelled tree is a couple , where and is an -colored -ordinal whose underlying set is and the coloring given by the arity of the corresponding vertex of .
Let be some complementary order on the underlying set of a -ordinal . We say that dominates if, for all ,
| (55) |
The pullback (54) represents the pruned -operad as a suboperad of the desymmetrisation of the operad whose arity- operations are -labelled trees such that dominates the canonical complementary order on the set of white vertices of .
Let us define the operadic category as the Grothendieck construction of Proposition 2.5 applied to the pruned -operad . By definition, the objects of are pairs of -labeled trees such that dominates the canonical complementary order on . The rest of this section will be devoted to the definition of a functor
| (56) |
where is the category of leveled trees introduced in Section 5.2. This functor will play a key rôle in Section 7.
We start by noticing that the set of 0,-0.20138916)(0.40277833,0.20138916) -vertices of has a natural lexicographic order defined by saying that if the level of is closer to the root than the level of ; if lies on the same level as then if and only if is on the left from in the sense of the planar structure of . Given a leveled tree , we consider an -labelled tree with , where is the functor in (40), the pruning functor, and produced from in four steps:
- (i)
labelling the white vertices of by using the above lexicographical order,
- (ii)
forgetting the level structure of ,
- (iii)
converting all 0,-0.20138916)(0.40277833,0.20138916) -vertices of to 0,-0.19711548)(0.39423096,0.19711548) -vertices and
- (iv)
contracting edges connecting two 0,-0.19711548)(0.39423096,0.19711548) -vertices and erasing all 0,-0.19711548)(0.39423096,0.19711548) -vertices of arity one.
As an exercise, we recommend to check that applying the above steps to the tree in Figure 2 produces the tree in Figure 4. To show that indeed means to verify that the -ordinal dominates the complementary order generated by .
Let in and let be the corresponding white vertices from . The relation means that, in , the vertex lies on the level closer to the root than the level of . There are two possibilities: either and are connected by a directed path and then in , or there is no such a directed path, in which case either or in . The domination condition (55) clearly holds for the pair in this case.
Assume that in . This means that precedes in the lexicographical order and also that there is no directed path connecting and in . Hence in which finishes the verification that dominates . The idea is indicated in Figure 5.
-4,-5.2676873)(26.71,2)
A morphism in is, by definition of the Grothendieck construction, an -tuple
| (57) |
where is a morphism of -ordinals, and , , are such that
| (58) |
where is the multiplication in the pruned -operad .
For any morphism in , the functor induces a map of -trees so, denoting and , we have the induced map
| (59) |
of -colored -ordinals.
To define the functor on morphisms, it suffices to specify it on elementary morphisms listed in Section 5.2. Let be an elementary morphism of Type 1 collapsing two consecutive levels. Each 0,-0.20138916)(0.40277833,0.20138916) -vertex of has the fiber . Such a also corresponds to a unique element of the -ordinal presented . So, we associate to the element . It is easy to check that then (58) with as above, and is satisfied, so we constructed a morphism in .
If is an elementary morphism of Type 2 that replaces a level of 0,-0.19711548)(0.39423096,0.19711548) -vertices by a level of 0,-0.20138916)(0.40277833,0.20138916) -vertices, then clearly and we define to be the identity morphism.
Assume that replaces a 0,-0.20138916)(0.40277833,0.20138916) -vertex of by a 0,-0.20138916)(0.40277833,0.20138916) -vertex and denote by the corresponding ‘exceptional’ element of the -ordinal . To describe the fibers of and of the induced map (59) denote, for , by the terminal -ordinal whose input and output colors equal , the initial -ordinal whose output color is , and by (resp. ) the 0,-0.20138916)(0.40277833,0.20138916) - (resp. 0,-0.20138916)(0.40277833,0.20138916) -) corolla of arity . With this notation,
where is the arity of a 0,-0.20138916)(0.40277833,0.20138916) -vertex of . The induced map (59) is an inclusion and
where denotes the color of . We define by taking in (57)
The discussion of Type 3 elementary morphisms is analogous. The exceptional fibers of are now the exceptional trees with no vertices, while the exceptional fibers of the induced map are the initial of -ordinals with the output color This completes the definition of the functor .
7. Action of the Tamarkin operad
The aim of this section is to prove the following statement in which is the Tamarkin operad recalled in Definition 6.1.
Theorem 7.1.
For any multiplicative -operad in a duoidal category one has a natural action
| (60) |
Proposition 2.5 associates to the operad the operadic category , together with a discrete operadic fibration
By (16), , therefore , so the map in (60) is the same as a morphism
| (61) |
On the other hand, define the operadic category using Proposition 1.9 as the pullback of operadic categories:
| (62) |
The induced functors of the associated categories of operads enjoy the Beck-Chevalley property by Proposition 2.8, so
| (63) |
The map in (61) is thus the same as a morphism
which is, by adjunction, the same as an operad morphism
Since clearly , Theorem 7.1 will be proved if we construct a natural morphism.
| (64) |
Remark 7.2.
Notice that together with (63) implies that , so is the result of the application of the functor inverse to the Grothendieck construction to the discrete fibration .
It is obvious that the diagram
in which is the functor (40) and the functor (56) commutes, so we have the induced operadic functor to the pullback of (62) as in the commutative diagram
| (65) |
Recall that we already constructed a canonical morphism (51) of -operads
By (65), , so . Noticing the isomorphism , we see that we therefore also have a natural morphism of -operads
| (66) |
The requisite map in (64) will be constructed by ‘inverting ’ in (66), using:
Lemma 7.3.
Let be an operadic functor and . Assume that is surjective on objects. Suppose we are also given a morphism of -operads such that, for arbitrary such that ,
| (67) |
Then there exist a unique morphism of -operads satisfying .
Proof Lemma 7.3.
For choose such that . Since and , we may define by . We leave as an exercise to verify that the collection is a well-defined morphism of operads. ∎
We wish to apply the lemma to the situation when , , is the functor in (65), , and the morphism of (66). Since is clearly surjective on objects, we only need to verify (67). In this particular case it means that, given such that , . Recalling again that and , we easily see that it is enough to prove:
Lemma 7.4.
Let be the composite (51). If are such that , then .
As the first step in proving Lemma 7.4 we characterize, in Lemma 7.6 below, pairs having the same -image in . For this, the following alternative description of objects of the categories and will be useful.
Lemma 7.5.
Objects of can be described as the isomorphism classes of planar rooted trees with white vertices 0,-0.20138916)(0.40277833,0.20138916) , vertical vertices 0,-0.20138916)(0.40277833,0.20138916) and horizontal vertices 0,-0.19711548)(0.39423096,0.19711548) . While 0,-0.20138916)(0.40277833,0.20138916) -vertices have arbitrary arities , 0,-0.19711548)(0.39423096,0.19711548) -vertices have either arity or , and all 0,-0.20138916)(0.40277833,0.20138916) -vertices are of arity .
We moreover require that has no internal edge connecting two 0,-0.19711548)(0.39423096,0.19711548) -vertices and no internal edge starting from a 0,-0.19711548)(0.39423096,0.19711548) -vertex and ending in a 0,-0.20138916)(0.40277833,0.20138916) -vertex, i.e. the following edges
| (68) | 0,-0.6230486)(4.146097,0.6230486) or 0,-0.6257164)(4.146097,0.6257164) |
are not allowed. Finally, 0,-0.20138916)(0.40277833,0.20138916) - and 0,-0.20138916)(0.40277833,0.20138916) -vertices are lined up in levels such that each level contains at least one 0,-0.20138916)(0.40277833,0.20138916) -vertex.
Objects of can similarly be identified with the isomorphisms classes of trees as above, but this time allowing also levels consisting solely of 0,-0.20138916)(0.40277833,0.20138916) -vertices.
Proof.
Let us denote provisionally by the set of isomorphism classes of trees which, according to the lemma, should describe objects of , and let be similarly related to . We are going to construct two couples of mutually inverse maps,
While the definitions of and are very simple, our constructions of their inverses will involve intuitive geometric arguments. A formal combinatorial construction should use a straightforward but lengthy induction on the number of vertices of the trees involved. We leave it to the interested reader.
Before we begin, notice that each planar rooted tree with levels of 0,-0.20138916)(0.40277833,0.20138916) - and 0,-0.20138916)(0.40277833,0.20138916) -vertices determines an -colored -tree by same procedure as described for the leveled trees of in Section 5.2. That is, we organize 0,-0.20138916)(0.40277833,0.20138916) - and 0,-0.20138916)(0.40277833,0.20138916) -vertices of to table (41); the -truncation of will then be the set and its -leaves the same as in (42). The -coloring of the -leaves of is given, as always in this article, by the arities of the corresponding 0,-0.20138916)(0.40277833,0.20138916) -vertices. It is clear that is pruned if and only if does not have levels consisting solely of 0,-0.20138916)(0.40277833,0.20138916) -vertices.
Let us describe . As in Section 6, the level structure of induces the lexicographic order on the set of its white vertices. We label the 0,-0.20138916)(0.40277833,0.20138916) -vertices of by accordingly, remove the levels and denote the resulting tree by .
Since, by assumption, all levels of contain at least one white vertex, the -tree is pruned and can therefore be interpreted as a -ordinal. Then, by construction, is an -labelled tree. It is moreover clear that the -ordinal dominates the canonical complementary order on , so in fact .
On the other hand, take and define as follows. First, organize the 0,-0.20138916)(0.40277833,0.20138916) -vertices of to levels such that . The domination condition for guarantees that it is possible. Then move the 0,-0.19711548)(0.39423096,0.19711548) -vertices of so close to the root that none of the edges 0,-0.6257164)(4.146097,0.257164) intersect a level line and that none of the 0,-0.19711548)(0.39423096,0.19711548) -vertices lies on a level line. Finally, introduce unary 0,-0.20138916)(0.40277833,0.20138916) -vertices at the intersection points of the level lines with the edges of . Then and are obviously mutual inverses.
For instance, if is the -colored -ordinal represented by the pruned -colored -tree in the right side of Figure 6
0,-1)(6.1622066,1.57) 0,-1)(4.79,1.57)
5.5,-5.555)(20.005621,3)
Let us describe . Notice that elements of are, by the definition via the pullback in (62), couples such that and , where is the pruning of the -colored -tree . We can call couples -labelled trees.
For denote by be the tree obtained from by removing levels all consisting only of 0,-0.20138916)(0.40277833,0.20138916) -vertices. Clearly , so it makes sense to put . It is then clear that the rule defines a map .
Let us construct its inverse . Suppose that . As we already observed, , so we may use the previous construction and consider, as an intermediate step, the tree . The tree will be constructed by adding additional levels of 0,-0.20138916)(0.40277833,0.20138916) -vertices of arity to as follows.
Let and . If , there is nothing to do as is pruned; in this case we take . Assume therefore that .
Since is a subset of , we have an inclusion . The complement is the disjoint union of non-empty intervals. For instance, for as Figure 6, , , , so
For , , such that , let . In the example above, , and . For each such an we add to new levels consisting of 0,-0.20138916)(0.40277833,0.20138916) -vertices of arity placed above the th level of so close to it that all vertices of above this level are also above these newly introduced levels. If 1010 10 This may obviously happen only when . we introduce new levels of 0,-0.20138916)(0.40277833,0.20138916) -vertices of arity intersecting the input leaves of .
We denote the resulting tree by and define . We believe that Figure 8 makes the construction of out of obvious.
5,-5.605)(20.025,4)
It is also clear that the maps and are inverse to each other, showing that . This finishes the proof. ∎
In the description of Lemma 7.5, the -image of a leveled tree in can be obtained in four steps. First we forget all type-(ii) levels of , so the 0,-0.19711548)(0.39423096,0.19711548) -vertices are allowed to move freely. In the second step we split all 0,-0.20138916)(0.40277833,0.20138916) -vertices of arity into one 0,-0.19711548)(0.39423096,0.19711548) -vertex of arity followed by 0,-0.20138916)(0.40277833,0.20138916) -vertices of arities , graphically:
1,-4.0)(14.735774,0)
The third step removes all internal edges starting at a 0,-0.19711548)(0.39423096,0.19711548) -vertex and ending at a 0,-0.20138916)(0.40277833,0.20138916) -vertex by allowing 0,-0.19711548)(0.39423096,0.19711548) -vertices to penetrate through 0,-0.20138916)(0.40277833,0.20138916) -vertices as in:
| 5,-2.2)(14.735774,0) |
In the final step we contract all edges connecting two horizontal vertices and remove horizontal vertices of arity . The result is the image .
We leave as an exercise to show that if we apply the above steps to the tree in Figure 2, we get the tree in Figure 9.
6.5,-5.75)(18.502516,4.9)
The following lemma describes all ’s in with the same -image.
Lemma 7.6.
Let . Then if and only if is obtained from by a finite sequence of the following elementary moves and their inverses:
- (i)
introducing a new level of horizontal vertices of arity one,
- (ii)
choosing two adjacent levels of horizontal vertices and contracting all edges connecting vertices in these two chosen levels, creating one level of horizontal vertices,
- (iii)
replacing an arity- vertical vertex followed by an arity- horizontal vertex with an arity- vertical vertex followed by an arity horizontal vertex:
5,-4.0)(14.735774,0)
- (iv)
replacing an arity- horizontal vertex followed by an arity- vertical vertex with an arity- horizontal vertex followed by an arity vertical vertex:
5,-4.0)(14.735774,0)
Notice that moves (iii) and (iv) are ‘local’ in that they do not change the level structure of and that one can be obtained from the other by interchanging the rôles of 0,-0.20138916)(0.40277833,0.20138916) and 0,-0.19711548)(0.39423096,0.19711548) .
Proof of Lemma 7.6.
It is immediate to see that none of the moves changes the -images. Therefore, if and differ by a sequence of the moves and their inverses, .
To prove the opposite implication, let us say that a leveled tree is in the canonical form, if has no levels consisting only of 0,-0.19711548)(0.39423096,0.19711548) -vertices of arity , and no internal edges as in (68). It is obvious that, if are in the canonical form, then if and only if in . The proof is finished by observing that each can be brought to the canonical form by a finite sequence of moves (i)–(iv) and their inverses. ∎
Lemma 7.7.
Proof.
Expanding the definitions we see that we must establish that the diagram
| (69) |
in which are the maps (47), the maps (53) and the operad compositions, commutes for each move of Lemma 7.6.
Move (i). Assume that is obtained from by adding a level of horizontal vertices of arity . It follows from the defining formula (45) that there are some such that
Likewise, it follows from (52) that there are some such that
The unitality axiom [9, Def. 4.1] for -operads then implies the commutativity of the diagram
which, along with the obvious commutativity of
implies the commutativity of (69).
Move (ii). By analyzing the definitions of the objects involved in (69), we easily see that its commutativity would follow from the commutativity of the diagram
| (70) |
whose left vertical arrow is constructed in [9, Example 4.5], and the remaining arrows are induced by the monoid structure of and by the canonical map .
Move (iii). The commutativity of (69) would in this case follow from the commutativity of
| (71) |
whose maps are induced by the comonoid structure of , monoid structure of and the canonical map .
8. Duoidal Deligne’s conjecture
Let be a complete -category and a cosimplicial object in . Recall [9, §5.2] that the -totalization of a cosimplicial object is the -enriched end
By Proposition 5.2 of [9], any multiplicative -operad in bears a canonical structure of a cosimplicial object in . In Definition 5.3 of [9] we introduced the Hochschild -object of a as the -totalization
We claim that the canonical cosimplicial structure on is induced by the action (60) of the -operad . By this we mean that the underlying category is the simplicial category and that , where is the functor (22) with and .
It follows from definition that the objects of the underlying category are natural numbers. Its hom-sets are
where is the terminal -tree with its unique -leaf colored by and the root by . Morphisms in are thus represented by trees as in Lemma 7.5 with one 0,-0.20138916)(0.40277833,0.20138916) -vertex of arity , no 0,-0.20138916)(0.40277833,0.20138916) -vertices, and leaves. It is obvious from this description that and have isomorphic underlying categories, while by [7, Lemma 2.5]. The identification is now a simple exercise. We conclude that
where is given by (23).
As we already recalled from [9, Prop. 4.9], the endomorphism -operad of a monoid in a -monoidal category is multiplicative. The Hochschild -object of was called the -center of and denoted
Since is a cocomplete symmetric monoidal category it has -tensors. For a set the tensor is equal to the coproduct of -copies of For any operadic category and any -operad in we can construct then an enrichment of in which on an object takes value By abusing notations we will denote such an enriched -operad by the same letter In particular we will consider the operad as a colored -operad in for any cocomplete
Proposition 4.6 immediately gives:
Theorem 8.1.
Let be a cosimplicial object in Then there is a canonical action of the -operad on the Hochschild object of a multiplicative -operad In particular, there is a canonical action of on the -center of any monoid in any -monoidal category
When is the category of chain complexes, is the chain -operad Ø considered by Tamarkin in [30, §5.2]. Let be the constant cosimplicial object whose all terms equal the unit object .
Proposition 8.2.
The -operad is isomorphic to the canonical -operad
Proof.
It is sufficient to observe that the value of the multitensor is the constant cosimplicial object for any . Indeed, if it is so, then clearly
where means the space of natural transformations (i.e. cosimplicial maps) between the constant cosimplicial objects .
It is clear that for each the coend in (19) equals the colimit of the -simplicial object , , so it is enough to check that the colimit of the -simplicial set is a one point set. This boils down to verification that the equivalence relation generated by the simplicial operators on has only one equivalence class.
Notice that, by the definition (18),
where is the -tree with its -leaves colored by and the root by . The elements of are thus represented by -labelled leveled trees whose 0,-0.20138916)(0.40277833,0.20138916) -vertices have no incoming edges. In this description, the two simplicial operators
| (73) |
in -th direction are local operations acting on a tree by the following surgery: ‘cut off’ the unique incoming edge of the th 0,-0.20138916)(0.40277833,0.20138916) -vertex of and then ‘glue’ it to the outcoming edge of this vertex in two possible ways introducing a new 0,-0.19711548)(0.39423096,0.19711548) -vertex, as indicated in Figure 10 – compare with the differential in the brace operad [8, Example 5.8].
2,-4.575521)(11.002144,.375521)
It is simple to prove by induction that any two trees from can be connected by a zig-zag of such elementary surgery operations, so the colimit of is a one-point set as claimed. ∎
The center of a monoid in a -monoidal category , defined as or, more explicitly, as the equalized (30), has a canonical structure of a duoid in by [9, Theorem 5.6]. On the other hand, according to [9, Example 11.15], duoids in are the same as -algebras in .1111 11 The operad was denoted in [9]. The following proposition is easy to prove.
Proposition 8.3.
The action of the operad equips with its canonical duoid structure.
Let now be a monoidal model category and be a standard system of simplices for in the sense of [16, Definition A.6]. Recall that this means that
- (i)
is cofibrant for the Reedy model structure on ,
- (ii)
is the unit object of and the simplicial operators act via weak equivalences in , and
- (iii)
the simplicial realization functor is a symmetric monoidal functor whose structural maps
are weak equivalences for Reedy-cofibrant objects .
Since , the canonical map of cosimplicial objects induces a map of -operads
Theorem 8.4.
Let be a standard system of simplices for a monoidal model category such that the lattice path operad is strongly -reductive in the sense of [7, Definition 3.7]. Then the canonical morphism of -operads
| (74) |
is a weak equivalence. In other words, the -operad is contractible.
Proof.
The proof follows closely the proof of Theorem 3.8 from [7], with the simplification that we do not need to take a colimit over the complete graph operads. The only fact we should know is that the map of -objects
is a weak equivalence for every In the notation used in the proof of [7, Theorem 3.8], the object on the left side is the same as for equal to It is shown at the end of the proof of [7, Theorem 3.8] that the map is a weak equivalence. ∎
The map induces a canonical map
| (75) |
The map (74) equips the duoid with a structure of -algebra such that (75) becomes a map of -algebras.
Let be a fibrant replacement of in the category of monoids with the projective model structure, and a standard system of simplices for . The -center of was called in [9] the homotopy center of . The above considerations imply the central result of our paper:
Corollary 8.5 (Duoidal Deligne’s conjecture).
Under the assumptions of Theorem 8.4, the Hochschild -object of a multiplicative -operad in a duoidal category admits an action of a contractible -operad.
The homotopy center of a monoid in a multiplicative -category admits an action of a contractible -operad that lifts the duoid structure on the center .
The assumptions of Theorem 8.4 are satisfied for instance when is the category of compactly generated topological spaces or chain complexes over a commutative ring, and the cosimplicial space of topological simplices or normalized cellular chains on topological simplices, respectively, see [7, Examples 3.10(a),(c)]. It is also not difficult to show that these assumptions are satisfied for with the Joyal-Tirney model structure and the cosimplicial chaotic groupoid on finite sets, cf. [9, Example 5.10].
On the other hand, it was shown in [7, Example 3.10(b)] that for the category of simplicial sets and the cosimplicial simplicial set of representables, the assumption of strongly -reductivity of the lattice operad fails. We however believe that the second part of Corollary 8.5 remains true even without this assumption, because taking fibrant replacement of should counterweight the poor homotopical property of We leave this refined version of Deligne’s conjecture as a subject for a future work.
References
- [1] M. Aguiar, S. Mahajan. Monoidal functors, species and Hopf algebras. CRM Monograph Series, AMS, 29, 2010.
- [2] C. Barwick. From operator categories to topological operads. Preprint arXiv:1302.5756, February 2013.
- [3] M.A. Batanin. Monoidal globular categories as a natural environment for the theory of weak -categories. Adv. Math., 136(1):39–103, 1998.
- [4] M.A. Batanin. Symmetrisation of -operads and compactification of real configuration spaces. Adv. Math., 211(2):684–725, 2007.
- [5] M.A. Batanin. The Eckmann-Hilton argument and higher operads. Adv. Math., 217(1):334–385, 2008.
- [6] M.A. Batanin and C. Berger. Homotopy theory for algebras over polynomial monads. Preprint, 2013.
- [7] M.A. Batanin and C. Berger. The lattice path operad and Hochschild cochains. In Alpine perspectives on algebraic topology, volume 504 of Contemp. Math., pages 23–52. Amer. Math. Soc., Providence, RI, 2009.
- [8] M.A. Batanin, C. Berger, and M. Markl. Operads of natural operations I: Lattice paths, braces and Hochschild cochains. In J.-L. Loday and B. Vallette, editors, Operads 2009, volume 26 of Sémin. Congr., pages 1–33. Soc. Math. France, Paris, 2011.
- [9] M.A. Batanin and M. Markl. Centers and homotopy centers in enriched monoidal categories. Adv. Math., 230(4-6):1811–1858, 2012.
- [10] M.A. Batanin and R. Street. The universal property of the multitude of trees. J. Pure Appl. Algebra, 154(1-3):3–13, 2000. Category theory and its applications (Montreal, QC, 1997).
- [11] M.A. Batanin and M. Weber. Algebras of higher operads as enriched categories. Appl. Categ. Structures, 19(1):93–135, 2011.
- [12] C. Berger. Combinatorial models for real configuration spaces and -operads. In J.L. Loday, J.D Stasheff, and A.A. Voronov, editors, Operads: Proceedings of Renaissance Conferences, volume 202 of Contemporary Math., pages 37–52. Amer. Math. Soc., 1997.
- [13] C. Berger. Private communication.
- [14] C. Berger and B. Fresse. Combinatorial operad actions on cochains. Math. Proc. Cambridge Philos. Soc., 137(1):135–174, 2004.
- [15] C. Berger and I. Moerdijk. Resolution of coloured operads and rectification of homotopy algebras. In Categories in algebra, geometry and mathematical physics, volume 431 of Contemp. Math., pages 31–58. Amer. Math. Soc., Providence, RI, 2007.
- [16] C. Berger and I. Moerdijk. The Boardman-Vogt resolution of operads in monoidal model categories. Topology, 45(5):807–849, February 2006.
- [17] J.M. Boardman and R.M. Vogt. Homotopy Invariant Algebraic Structures on Topological Spaces. Springer-Verlag, 1973.
- [18] B. Day and R. Street. Abstract substitution in enriched categories. J. Pure Appl. Algebra, 179(1-2):49–63, 2003.
- [19] B. Day and R. Street. Lax monoids, pseudo-operads, and convolution. In Diagrammatic morphisms and applications (San Francisco, CA, 2000), volume 318 of Contemp. Math., pages 75–96. Amer. Math. Soc., Providence, RI, 2003.
- [20] S. Forcey. Enrichment over iterated monoidal categories. Algebr. Geom. Topol., 4:95–119 (electronic), 2004.
- [21] E. Getzler and M.M. Kapranov. Modular operads. Compos. Math., 110(1):65–126, 1998.
- [22] R. Gordon, A.J. Power, and R. Street. Coherence for Tricategories, volume 558 of Mem. Amer. Math. Soc. AMS, 1995.
- [23] M.M. Kapranov. Analogies between the Langlands correspondence and topological quantum field theory. In Functional analysis on the eve of the 21st century, Vol. 1 (New Brunswick, NJ, 1993), volume 131 of Progr. Math., pages 119–151. Birkhäuser Boston, Boston, MA, 1995.
- [24] R.M. Kaufmann and B.C. Ward. Feynman Categories. Preprint arXiv:1312.1269, December 2013.
- [25] A. Kock. Strong functors and monoidal monads. Archiv der Math. 23: 113–120, (1972).
- [26] M. Markl. Operads and PROPs. In Handbook of algebra. Vol. 5, volume 5 of Handb. Algebr., pages 87–140. Elsevier/North-Holland, Amsterdam, 2008.
- [27] M. Markl, S. Shnider, and J.D. Stasheff. Operads in algebra, topology and physics, volume 96 of Mathematical Surveys and Monographs. American Mathematical Society, Providence, RI, 2002.
- [28] J.E. McClure and J.H. Smith. A solution of Deligne’s Hochschild cohomology conjecture. In Recent progress in homotopy theory (Baltimore, MD, 2000), volume 293 of Contemp. Math., pages 153–193. Amer. Math. Soc., Providence, RI, 2002.
- [29] S. Mac Lane and I. Moerdijk. Sheaves in geometry and logic. Universitext. Springer-Verlag, New York, 1994. A first introduction to topos theory, Corrected reprint of the 1992 edition.
- [30] D. Tamarkin. What do dg-categories form? Compos. Math., 143(5):1335–1358, 2007.
- [31] D. Tamarkin and B. Tsygan. Cyclic formality and index theorems. Lett. Math. Phys., 56:85–97, 2001.